@@ -13,10 +13,11 @@ def get_base_url():
 
 
 class LaunchableClient:
-    def __init__(self, token: str, base_url: str = "", session: requests.Session = requests.Session()):
+    def __init__(self, token: str, base_url: str = "", session: requests.Session = requests.Session(), test_runner: str = ""):
         self.base_url = base_url or get_base_url()
         self.session = session
         self.token = token
+        self.test_runner = test_runner
 
     def request(self, method, path, **kwargs):
         headers = kwargs.pop("headers")
@@ -34,7 +35,12 @@ class LaunchableClient:
             raise Exception("unable to post to %s" % url) from e
 
     def _headers(self):
-        return {
+        h = {
             "User-Agent": "Launchable/{} (Python {}, {})".format(__version__, platform.python_version(), platform.platform()),
-            'Authorization': 'Bearer {}'.format(self.token)
+            'Authorization': 'Bearer {}'.format(self.token),
         }
+
+        if self.test_runner != "":
+            h["launchable-test-runner"] = self.test_runner
+
+        return h
